pub struct MenuType {
pub key: Identifier,
pub slot_count: usize,
}Expand description
Represents a menu type (container/GUI type) in Minecraft. Menu types define the different inventory interfaces available, such as chests, furnaces, anvils, etc.
Fields
key: Identifierslot_count: usizeTotal number of slots constructed by the client menu, including the player’s inventory slots when that menu displays them.